/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015 Renesas Electronics Corporation. All rights re
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_cg_amp.c
* Version      : 
* Device(s)    : R5F117GCG
* Tool-Chain   : IAR Systems iccrl78
* Description  : This file implements device driver for AMP module.
* Creation Date: 10/01/2015
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_amp.h"
/* Start user code for include. Do not edit comment generated here */
#include "r_cg_it.h"
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Start user code for global. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_AMP_Create
* Description  : This function initializes the operational amplifier.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_AMP_Create(void)
{
    PMC1 |= 0xFC;                     /* Analog mode */
    PMC2 |= 0x3F;                     /* Analog mode */

    PM1 |= 0xFC;                      /* Input mode */
    PM2 |= 0x3F;                      /* Input mode */

    AMPC   = 0x00;                    /* Stop all operational amplifiers and reference current. */
    AMPSP  = 0U;                      /* Low power mode */
    AMPTRS = 0x01U;                   /* AMP0 and AMP1 are triggerred by ELC trigger 0 */
    AMPTRM = 0x00U;                   /* Software trigger mode */
}

/* Start user code for adding. Do not edit comment generated here */
/***********************************************************************************************************************
* Function Name: AMP_LPF_Start
* Description  : This function starts AMP module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void AMP_LPF_Start(void)
{
    amp_state = AMP_STATE_START;
    IREFE = 1U;	
    R_IT00_Start();
}

/***********************************************************************************************************************
* Function Name: AMP_LPF_Stop
* Description  : This function starts AMP module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void AMP_LPF_Stop(void)
{
    //amp_state = AMP_STATE_STOP;
    AMPC &= 0xFC;                      /* Disable AMP0 and AMP1 */
    IREFE = 0U;	
}
/***********************************************************************************************************************
* Function Name: AMP_HPF_Start
* Description  : This function starts AMP module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void AMP_HPF_Start(void)
{
    
    IREFE = 1U;	
    AMPC |= 0x0C;                       /* Enable AMP2 and AMP3 */
}

/***********************************************************************************************************************
* Function Name: AMP_HPF_Stop
* Description  : This function starts AMP module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void AMP_HPF_Stop(void)
{
    //amp_state = AMP_STATE_STOP;
    AMPC &= 0xF3;                      /* Disable AMP2 and AMP3 */
    IREFE = 0U;	
}
/* End user code. Do not edit comment generated here */
